@@ -57,12 +57,6 @@ class ZipFile:
     """
     Download a zipped CSV file containing all countries and all categories
     from the EUROSTAT webserver.
-
-    The original strategy to convert colons to NaN was the following:
-
-        # If there is a colon in a cell, it's not a number #
-        def colon_to_nan(cell): return numpy.NaN if ':' in cell else cell
-        df = df.applymap(colon_to_nan)
     """
 
     base_url   = "https://ec.europa.eu/eurostat/estat-navtree-portlet-prod/" \
@@ -84,25 +78,30 @@ class ZipFile:
 
     # ---------------------------- Properties --------------------------------#
     @property
-    def cache_is_valid(self, check_md5=True):
+    def cache_is_valid(self):
         """Checks if the file needed has been correctly downloaded."""
-        # Simple case #
+        # Check existence #
         if not self.zip_path.exists: return False
-        if not check_md5:            return True
-        # Check the MD5 #
-        return self.zip_path.md5 == self.md5
+        # Return #
+        return True
 
     @property
     def raw_csv(self):
         """
         Loads the big CSV that's inside the ZIP into memory.
         We don't specify na_values = [':', ': '] here because it's done later.
+
+        The original strategy to convert colons to NaN was the following:
+
+            # If there is a colon in a cell, it's not a number #
+            def colon_to_nan(cell): return numpy.NaN if ':' in cell else cell
+            df = df.applymap(colon_to_nan)
         """
         # Check the cache #
         if not self.cache_is_valid:
             self.refresh_cache()
             if not self.cache_is_valid:
-                raise Exception("Error refreshing cache")
+                raise Exception("Error refreshing cache.")
         # Load the CSV #
         with gzip.open(self.zip_path) as csv_handle:
             text_mode = io.TextIOWrapper(csv_handle, encoding=self.encoding)
@@ -117,8 +116,10 @@ class ZipFile:
         df = df.rename(columns={'geo\\time': 'country'})
         # Also many column names have trailing whitespace #
         df.columns = df.columns.str.strip().str.replace(' ','_')
+        # Determine the years available in the dataset #
+        years = [int(col) for col in df.columns if col.isnumeric()]
         # Some cells have a number and a character or just a character #
-        for col in map(str, (2016, 2014, 2012, 2010, 2008, 2006, 2004)):
+        for col in map(str, years):
             df[col] = df[col].apply(pandas.to_numeric, errors = 'coerce')
         # Return #
         return df
@@ -157,7 +158,6 @@ class WasteGen(ZipFile):
     zip_name   = "env_wasgen.tsv.gz"
     csv_name   = "env_wasgen.tsv"
     encoding   = "ISO-8859-1"
-    md5        = "df2ab56bb48bb2bf0e3266d08fa4d408"
 
 #-----------------------------------------------------------------------------#
 class WasteTrt(ZipFile):
@@ -169,7 +169,6 @@ class WasteTrt(ZipFile):
     zip_name   = "env_wastrt.tsv.gz"
     csv_name   = "env_wastrt.tsv"
     encoding   = "ISO-8859-1"
-    md5        = "bfbfc036921b22698e52eab168f3f891"
 
 ###############################################################################
 # Create singletons #
